aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorChris Lahey <clahey@src.gnome.org>2002-02-07 19:26:12 +0800
committerChris Lahey <clahey@src.gnome.org>2002-02-07 19:26:12 +0800
commitea82c78d9629831497e529c2b56db7af88e89efb (patch)
tree88f5d1273a31c83279a828fdf54100242cf9bdc9
parentb7ac37f6b1b54cf9262958a4419f00d00dea554e (diff)
downloadgsoc2013-evolution-ea82c78d9629831497e529c2b56db7af88e89efb.tar
gsoc2013-evolution-ea82c78d9629831497e529c2b56db7af88e89efb.tar.gz
gsoc2013-evolution-ea82c78d9629831497e529c2b56db7af88e89efb.tar.bz2
gsoc2013-evolution-ea82c78d9629831497e529c2b56db7af88e89efb.tar.lz
gsoc2013-evolution-ea82c78d9629831497e529c2b56db7af88e89efb.tar.xz
gsoc2013-evolution-ea82c78d9629831497e529c2b56db7af88e89efb.tar.zst
gsoc2013-evolution-ea82c78d9629831497e529c2b56db7af88e89efb.zip
Missed one.
svn path=/trunk/; revision=15593
-rw-r--r--addressbook/ChangeLog3
-rw-r--r--addressbook/gui/widgets/e-addressbook-view.h8
2 files changed, 7 insertions, 4 deletions
diff --git a/addressbook/ChangeLog b/addressbook/ChangeLog
index 7b9a7cf822..ee2ba67f15 100644
--- a/addressbook/ChangeLog
+++ b/addressbook/ChangeLog
@@ -1,6 +1,7 @@
2002-02-07 Christopher James Lahey <clahey@ximian.com>
- * gui/widgets/e-addressbook-view.c
+ * gui/widgets/e-addressbook-view.c,
+ gui/widgets/e-addressbook-view.h
(e_addressbook_view_setup_menus): Changed this function to use the
new GalViewMenus which takes a GalViewInstance, instead of a
GalViewCollection.
diff --git a/addressbook/gui/widgets/e-addressbook-view.h b/addressbook/gui/widgets/e-addressbook-view.h
index 9c9ccce8da..98258ab88c 100644
--- a/addressbook/gui/widgets/e-addressbook-view.h
+++ b/addressbook/gui/widgets/e-addressbook-view.h
@@ -22,7 +22,7 @@
#include <gtk/gtktable.h>
#include <bonobo/bonobo-ui-component.h>
-#include <gal/menus/gal-view-collection.h>
+#include <gal/menus/gal-view-instance.h>
#include "e-addressbook-model.h"
#include "widgets/menus/gal-view-menus.h"
#include "addressbook/backend/ebook/e-book.h"
@@ -79,9 +79,11 @@ struct _EAddressbookView
GtkWidget *vbox;
- /* Menus handler and the view collection */
- GalViewCollection *view_collection;
+ /* Menus handler and the view instance */
+ GalViewInstance *view_instance;
GalViewMenus *view_menus;
+ GalView *current_view;
+ BonoboUIComponent *uic;
};
struct _EAddressbookViewClass